<?php

namespace Drupal\layoutbuilder_extras\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class LayoutBuilderExtrasSettingsForm extends ConfigFormBase {

  const settingsName = 'layoutbuilder_extras.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'layoutbuilder_extras';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      self::settingsName,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $config = $this->config(self::settingsName);

    $form['enable_redirect_on_save'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable redirect to layout builder on node save'),
      '#description' => $this->t('Redirects to layout builder on node save (Where layout builder is enabled for).'),
      '#default_value' => $config->get('enable_redirect_on_save') ??
        TRUE
    ];

    $form['enable_configure_ajax_save'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable layout builder configure form live changes'),
      '#description' => $this->t('On a LB section form this will enable live changes.'),
      '#default_value' => $config->get('enable_configure_ajax_save') ??
        TRUE
    ];

    $form['remove_empty_divs'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Remove empty DIVS'),
      '#description' => $this->t('On rendering LB there might be empty fields, this will remove the empty wrappers left behind by the TPLs and stuff.'),
      '#default_value' => $config->get('remove_empty_divs') ??
        TRUE
    ];

    $form['enable_drag_handle_icon'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable drag handle icon'),
      '#description' => $this->t('The layout builder sidebar can be dragged, this just adds an icon to improve UX and visibility.'),
      '#default_value' => $config->get('enable_drag_handle_icon') ??
        TRUE
    ];


    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $config = $this->configFactory->getEditable(self::settingsName);

    $config->set('enable_redirect_on_save', $form_state->getValue('enable_redirect_on_save', FALSE));
    $config->set('enable_configure_ajax_save', $form_state->getValue('enable_configure_ajax_save', FALSE));
    $config->set('remove_empty_divs', $form_state->getValue('remove_empty_divs', FALSE));
    $config->set('enable_drag_handle_icon', $form_state->getValue('enable_drag_handle_icon', FALSE));

    $config->save();
  }

}
